emacs-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[Emacs-diffs] trunk r117662: Fix a few ``MS-DOG''s overlooked in the pre


From: Reuben Thomas
Subject: [Emacs-diffs] trunk r117662: Fix a few ``MS-DOG''s overlooked in the previous commit.
Date: Thu, 07 Aug 2014 10:17:28 +0000
User-agent: Bazaar (2.6b2)

------------------------------------------------------------
revno: 117662
revision-id: address@hidden
parent: address@hidden
committer: Reuben Thomas <address@hidden>
branch nick: trunk
timestamp: Thu 2014-08-07 11:15:52 +0100
message:
  Fix a few ``MS-DOG''s overlooked in the previous commit.
  
  * README: ``MSDOG'' becomes ``MS-DOS''.
  * lisp/arc-mode.el: Fix a couple of ``MS-DOG''s missed in the previous
  commit.
  * lisp/file-mode.el: ditto.
  * src/editfns.c: Fix a couple of ``MS-DOG''s missed in the previous commit.
  * src/xfaces.c: ditto.
modified:
  ChangeLog                      changelog-20091113204419-o5vbwnq5f7feedwu-1538
  README                         readme-20091113204419-o5vbwnq5f7feedwu-1539
  lisp/ChangeLog                 changelog-20091113204419-o5vbwnq5f7feedwu-1432
  lisp/arc-mode.el               arcmode.el-20091113204419-o5vbwnq5f7feedwu-877
  lisp/files.el                  files.el-20091113204419-o5vbwnq5f7feedwu-265
  src/ChangeLog                  changelog-20091113204419-o5vbwnq5f7feedwu-1438
  src/editfns.c                  editfns.c-20091113204419-o5vbwnq5f7feedwu-255
  src/xfaces.c                   xfaces.c-20091113204419-o5vbwnq5f7feedwu-560
=== modified file 'ChangeLog'
--- a/ChangeLog 2014-08-04 18:44:49 +0000
+++ b/ChangeLog 2014-08-07 10:15:52 +0000
@@ -1,3 +1,7 @@
+2014-08-07  Reuben Thomas  <address@hidden>
+
+       * README: ``MSDOG'' becomes ``MS-DOS''.
+
 2014-08-04  Paul Eggert  <address@hidden>
 
        Merge from gnulib, incorporating:

=== modified file 'README'
--- a/README    2014-06-26 06:55:15 +0000
+++ b/README    2014-08-07 10:15:52 +0000
@@ -84,7 +84,7 @@
 `doc/lispref'   holds the source code for the Emacs Lisp reference manual.
 `doc/lispintro' holds the source code for the Introduction to Programming
                 in Emacs Lisp manual.
-`msdos'     holds configuration files for compiling Emacs under MSDOG.
+`msdos'     holds configuration files for compiling Emacs under MS-DOS.
 `nextstep'  holds instructions and some other files for compiling the
             Nextstep port of Emacs, for GNUstep and Mac OS X Cocoa.
 `nt'        holds various command files and documentation files that pertain

=== modified file 'lisp/ChangeLog'
--- a/lisp/ChangeLog    2014-08-07 09:55:09 +0000
+++ b/lisp/ChangeLog    2014-08-07 10:15:52 +0000
@@ -2,6 +2,14 @@
 
        Refer to MS-DOS using the same name everywhere.
 
+       * arc-mode.el: Fix a couple of ``MS-DOG''s missed in the previous
+       commit.
+       * file-mode.el: ditto.
+
+2014-08-07  Reuben Thomas  <address@hidden>
+
+       Refer to MS-DOS using the same name everywhere.
+
        * arc-mode.el: ``MS-DOG'', ``MSDOG'' and ``msdog'' become
        ``MS-DOS''.
        * frame.el: ditto.

=== modified file 'lisp/arc-mode.el'
--- a/lisp/arc-mode.el  2014-08-07 09:55:09 +0000
+++ b/lisp/arc-mode.el  2014-08-07 10:15:52 +0000
@@ -31,7 +31,7 @@
 ;; understand the directory level of the archives.  For this reason,
 ;; you should expect this code to need more fiddling than tar-mode.el
 ;; (although it at present has fewer bugs :-)  In particular, I have
-;; not tested this under Ms-Dog myself.
+;; not tested this under MS-DOS myself.
 ;; -------------------------------------
 ;; INTERACTION: arc-mode.el should play together with
 ;;

=== modified file 'lisp/files.el'
--- a/src/ChangeLog     2014-08-05 08:25:28 +0000
+++ b/src/ChangeLog     2014-08-07 10:15:52 +0000
@@ -1,3 +1,11 @@
+2014-08-07  Reuben Thomas  <address@hidden>
+
+       Refer to MS-DOS using the same name everywhere.
+
+       * editfns.c: Fix a couple of ``MS-DOG''s missed in the previous
+       commit.
+       * xfaces.c: ditto.
+
 2014-08-05  Martin Rudalics  <address@hidden>
 
        * w32term.c (w32_redeem_scroll_bar):

=== modified file 'src/editfns.c'
--- a/src/editfns.c     2014-08-03 15:38:52 +0000
+++ b/src/editfns.c     2014-08-07 10:15:52 +0000
@@ -112,7 +112,7 @@
   pw = getpwuid (getuid ());
 #ifdef MSDOS
   /* We let the real user name default to "root" because that's quite
-     accurate on MSDOG and because it lets Emacs find the init file.
+     accurate on MS-DOS and because it lets Emacs find the init file.
      (The DVX libraries override the Djgpp libraries here.)  */
   Vuser_real_login_name = build_string (pw ? pw->pw_name : "root");
 #else

=== modified file 'src/xfaces.c'
--- a/src/xfaces.c      2014-07-19 15:18:23 +0000
+++ b/src/xfaces.c      2014-08-07 10:15:52 +0000
@@ -1068,7 +1068,7 @@
        return XCAR (coldesc);
     }
 #ifdef MSDOS
-  /* We can have an MSDOG frame under -nw for a short window of
+  /* We can have an MS-DOS frame under -nw for a short window of
      opportunity before internal_terminal_init is called.  DTRT.  */
   if (FRAME_MSDOS_P (f) && !inhibit_window_system)
     return msdos_stdcolor_name (idx);


reply via email to

[Prev in Thread] Current Thread [Next in Thread]
--- a/lisp/files.el     2014-07-28 09:39:09 +0000
+++ b/lisp/files.el     2014-08-07 10:15:52 +0000
@@ -2412,11 +2412,10 @@
      ("\\.by\\'" . bovine-grammar-mode)
      ("\\.wy\\'" . wisent-grammar-mode)
      ;; .emacs or .gnus or .viper following a directory delimiter in
      ;; Unix, MSDOG or VMS syntax.
      ("[]>:/\\]\\..*\\(emacs\\|gnus\\|viper\\)\\'" . emacs-lisp-mode)
      ("\\`\\..*emacs\\'" . emacs-lisp-mode)
-     ;; _emacs following a directory delimiter
-     ;; in MsDos syntax
+     ;; _emacs following a directory delimiter in MS-DOS syntax
      ("[:/]_emacs\\'" . emacs-lisp-mode)
      ("/crontab\\.X*[0-9]+\\'" . shell-script-mode)
      ("\\.ml\\'" . lisp-mode)
@@ -2439,7 +2438,7 @@
      ("\\.\\(asn\\|mib\\|smi\\)\\'" . snmp-mode)
      ("\\.\\(as\\|mi\\|sm\\)2\\'" . snmpv2-mode)
      ("\\.\\(diffs?\\|patch\\|rej\\)\\'" . diff-mode)
-     ("\\.\\(dif\\|pat\\)\\'" . diff-mode) ; for MSDOG
+     ("\\.\\(dif\\|pat\\)\\'" . diff-mode) ; for MS-DOS
      ("\\.[eE]?[pP][sS]\\'" . ps-mode)
      
@@ -2412,11 +2412,10 @@
      ("\\.wy\\'" . wisent-grammar-mode)
      ;; .emacs or .gnus or .viper following a directory delimiter in
-     ;; Unix, MSDOG or VMS syntax.
+     ;; Unix or MS-DOS syntax.
      ("[]>:/\\]\\..*\\(emacs\\|gnus\\|viper\\)\\'" . emacs-lisp-mode)
      ("\\`\\..*emacs\\'" . emacs-lisp-mode)
("\\.\\(?:PDF\\|DVI\\|OD[FGPST]\\|DOCX?\\|XLSX?\\|PPTX?\\|pdf\\|djvu\\|dvi\\|od[fgpst]\\|docx?\\|xlsx?\\|pptx?\\)\\'"
 . doc-view-mode-maybe)
      ("configure\\.\\(ac\\|in\\)\\'" . autoconf-mode)

=== modified file 'src/ChangeLog'